import { PLACEHOLDER } from "./constants";
import { FunctionComponent, ReactElement } from "react";
import { OptionProps } from "../Option";
import { MarkedInputProps } from "./MarkedInput";
import { Trigger } from "./hooks/useTrigger";
import { EventBus } from "./utils/EventBus";
export declare type Mark = {
    annotation: string;
    label: string;
    value: string;
    index: number;
    input: string;
    childIndex: number;
};
export interface OverlayProps {
    style: {
        left: number;
        top: number;
    };
    onSelect: onSelect;
    data: string[];
    word: string;
}
export interface MarkProps {
    label: string;
    value?: string;
}
export declare type onSelect = ({ label, value }: {
    label: string;
    value: string;
}) => void;
declare type label = `${string}${PLACEHOLDER.LABEL}${string}`;
declare type value = `${string}${PLACEHOLDER.VALUE}${string}`;
export declare type Markup = `${label}${value}` | `${label}`;
export declare type ElementOptions<T> = ReactElement<OptionProps<T>> | ReactElement<OptionProps<T>>[];
/** Piece of marked text: fragment of text or mark definition */
export declare type Piece = string | Mark;
export declare type KeyedPieces = Map<number, Piece>;
declare type PartialPick<T, F extends keyof T> = Omit<Required<T>, F> & Partial<Pick<T, F>>;
export declare type OptionType = PartialPick<OptionProps, "initMark" | "initOverlay">;
export declare type Options = OptionType[];
export declare type ConfiguredMarkedInputProps<T, T1 = OverlayProps> = Omit<MarkedInputProps<T, T1>, "Mark" | "Overlay" | "children">;
export declare type ConfiguredMarkedInput<T, T1 = OverlayProps> = FunctionComponent<ConfiguredMarkedInputProps<T, T1>>;
export declare type Store = {
    props: MarkedInputProps<any, any>;
    options: Options;
    pieces: KeyedPieces;
    trigger?: Trigger;
    bus: EventBus;
};
export declare type EventName = `on${string}`;
export declare enum Type {
    Change = 0,
    Delete = 1
}
export declare type Payload = {
    key: number;
    value?: Piece;
};
export {};
//# sourceMappingURL=types.d.ts.map